@@ -12,7 +12,7 @@ import (
 
 func main() {
 	var wg sync.WaitGroup
-	// passed &wg will be accounted at p.Wait() call
+	// passed wg will be accounted at p.Wait() call
 	p := mpb.New(mpb.WithWaitGroup(&wg))
 	total, numBars := 100, 3
 	wg.Add(numBars)
@@ -30,7 +30,7 @@ func main() {
 				// replace ETA decorator with "done" message, OnComplete event
 				decor.OnComplete(
 					// ETA decorator with ewma age of 60
-					decor.EwmaETA(decor.ET_STYLE_GO, 60), "done",
+					decor.EwmaETA(decor.ET_STYLE_GO, 60, decor.WCSyncWidth), "done",
 				),
 			),
 		)
@@ -50,6 +50,6 @@ func main() {
 			}
 		}()
 	}
-	// Waiting for passed &wg and for all bars to complete and flush
+	// wait for passed wg and for all bars to complete and flush
 	p.Wait()
 }
