@@ -12,6 +12,7 @@ import (
 
 func main() {
 	var wg sync.WaitGroup
+	// passed wg will be accounted at p.Wait() call
 	p := mpb.New(mpb.WithWaitGroup(&wg))
 	total := 100
 	numBars := 3
@@ -24,29 +25,31 @@ func main() {
 			mpb.BarOptional(mpb.BarRemoveOnComplete(), i == 0),
 			mpb.PrependDecorators(
 				decor.Name(name),
-				decor.EwmaETA(decor.ET_STYLE_GO, 60, decor.WCSyncSpace),
 			),
-			mpb.AppendDecorators(decor.Percentage()),
+			mpb.AppendDecorators(
+				decor.Any(func(s decor.Statistics) string {
+					return fmt.Sprintf("completed: %v", s.Completed)
+				}, decor.WCSyncSpaceR),
+				decor.Any(func(s decor.Statistics) string {
+					return fmt.Sprintf("aborted: %v", s.Aborted)
+				}, decor.WCSyncSpaceR),
+				decor.OnComplete(decor.NewPercentage("%d", decor.WCSyncSpace), "done"),
+				decor.OnAbort(decor.NewPercentage("%d", decor.WCSyncSpace), "ohno"),
+			),
 		)
 		go func() {
 			defer wg.Done()
 			rng := rand.New(rand.NewSource(time.Now().UnixNano()))
 			max := 100 * time.Millisecond
 			for i := 0; !bar.Completed(); i++ {
-				// start variable is solely for EWMA calculation
-				// EWMA's unit of measure is an iteration's duration
-				start := time.Now()
 				if bar.ID() == 2 && i >= 42 {
-					// aborting and removing while bar is running
-					bar.Abort(true)
+					bar.Abort(false)
 				}
 				time.Sleep(time.Duration(rng.Intn(10)+1) * max / 10)
 				bar.Increment()
-				// we need to call DecoratorEwmaUpdate to fulfill ewma decorator's contract
-				bar.DecoratorEwmaUpdate(time.Since(start))
 			}
 		}()
 	}
-
+	// wait for passed wg and for all bars to complete and flush
 	p.Wait()
 }
