@@ -12,20 +12,14 @@ import (
 
 func main() {
 	var wg sync.WaitGroup
-	// pass &wg (optional), so p will wait for it eventually
+	// passed wg will be accounted at p.Wait() call
 	p := mpb.New(mpb.WithWaitGroup(&wg))
 	total, numBars := 100, 3
 	wg.Add(numBars)
 
 	for i := 0; i < numBars; i++ {
 		name := fmt.Sprintf("Bar#%d:", i)
-		bs := mpb.BarStyle()
-		if i == 1 {
-			// reverse Bar#1
-			bs = bs.Tip("<").Reverse()
-		}
-		bar := p.Add(int64(total),
-			mpb.NewBarFiller(bs),
+		bar := p.New(int64(total), condBuilder(i == 1),
 			mpb.PrependDecorators(
 				// simple name decorator
 				decor.Name(name),
@@ -56,6 +50,17 @@ func main() {
 			}
 		}()
 	}
-	// Waiting for passed &wg and for all bars to complete and flush
+	// wait for passed wg and for all bars to complete and flush
 	p.Wait()
 }
+
+func condBuilder(cond bool) mpb.BarFillerBuilder {
+	return mpb.BarFillerBuilderFunc(func() mpb.BarFiller {
+		bs := mpb.BarStyle()
+		if cond {
+			// reverse Bar on cond
+			bs = bs.Tip("<").Reverse()
+		}
+		return bs.Build()
+	})
+}
