@@ -16,10 +16,8 @@ const (
 
 func main() {
 	var wg sync.WaitGroup
-	p := mpb.New(
-		mpb.WithWaitGroup(&wg),
-		mpb.WithRefreshRate(50*time.Millisecond),
-	)
+	// passed wg will be accounted at p.Wait() call
+	p := mpb.New(mpb.WithWaitGroup(&wg))
 	wg.Add(totalBars)
 
 	for i := 0; i < totalBars; i++ {
@@ -47,6 +45,6 @@ func main() {
 			}
 		}()
 	}
-
+	// wait for passed wg and for all bars to complete and flush
 	p.Wait()
 }
