@@ -63,7 +63,7 @@ func TestBarSetRefill(t *testing.T) {
 	till := 30
 	refiller := "+"
 
-	bar := p.Add(int64(total), mpb.NewBarFiller(mpb.BarStyle().Refiller(refiller)), mpb.BarFillerTrim())
+	bar := p.New(int64(total), mpb.BarStyle().Refiller(refiller), mpb.BarFillerTrim())
 
 	bar.SetRefill(int64(till))
 	bar.IncrBy(till)
@@ -152,7 +152,7 @@ func TestBarStyle(t *testing.T) {
 	bs.Tip(string(runes[2]))
 	bs.Padding(string(runes[3]))
 	bs.Rbound(string(runes[4]))
-	bar := p.Add(int64(total), mpb.NewBarFiller(bs), mpb.BarFillerTrim())
+	bar := p.New(int64(total), bs, mpb.BarFillerTrim())
 
 	for i := 0; i < total; i++ {
 		bar.Increment()
@@ -255,24 +255,27 @@ func TestBarPanicAfterComplete(t *testing.T) {
 }
 
 func TestDecorStatisticsAvailableWidth(t *testing.T) {
+	total := 100
+	down := make(chan struct{})
+	checkDone := make(chan struct{})
 	td1 := func(s decor.Statistics) string {
 		if s.AvailableWidth != 80 {
 			t.Errorf("expected AvailableWidth %d got %d\n", 80, s.AvailableWidth)
 		}
 		return fmt.Sprintf("\x1b[31;1;4m%s\x1b[0m", strings.Repeat("0", 20))
 	}
-	checkDone := make(chan struct{})
 	td2 := func(s decor.Statistics) string {
 		defer func() {
-			checkDone <- struct{}{}
+			select {
+			case checkDone <- struct{}{}:
+			default:
+			}
 		}()
 		if s.AvailableWidth != 40 {
 			t.Errorf("expected AvailableWidth %d got %d\n", 40, s.AvailableWidth)
 		}
 		return ""
 	}
-	total := 100
-	down := make(chan struct{})
 	p := mpb.New(
 		mpb.WithWidth(100),
 		mpb.WithShutdownNotifier(down),
@@ -293,7 +296,7 @@ func TestDecorStatisticsAvailableWidth(t *testing.T) {
 		for {
 			select {
 			case <-checkDone:
-				bar.Abort(false)
+				bar.Abort(true)
 			case <-down:
 				return
 			}
