@@ -2,10 +2,9 @@ package decor
 
 import (
 	"fmt"
-	"io"
 	"strconv"
 
-	"github.com/vbauerster/mpb/v5/internal"
+	"github.com/vbauerster/mpb/v7/internal"
 )
 
 type percentageType float64
@@ -24,12 +23,12 @@ func (s percentageType) Format(st fmt.State, verb rune) {
 		}
 	}
 
-	io.WriteString(st, strconv.FormatFloat(float64(s), 'f', prec, 64))
-
+	osw := optimisticStringWriter(st)
+	osw(strconv.FormatFloat(float64(s), 'f', prec, 64))
 	if st.Flag(' ') {
-		io.WriteString(st, " ")
+		osw(" ")
 	}
-	io.WriteString(st, "%")
+	osw("%")
 }
 
 // Percentage returns percentage decorator. It's a wrapper of NewPercentage.
@@ -50,7 +49,7 @@ func NewPercentage(format string, wcc ...WC) Decorator {
 	if format == "" {
 		format = "% d"
 	}
-	f := func(s *Statistics) string {
+	f := func(s Statistics) string {
 		p := internal.Percentage(s.Total, s.Current, 100)
 		return fmt.Sprintf(format, percentageType(p))
 	}
